# This code is part of qtealeaves.
#
# This code is licensed under the Apache License, Version 2.0. You may
# obtain a copy of this license in the LICENSE.txt file in the root directory
# of this source tree or at http://www.apache.org/licenses/LICENSE-2.0.
#
# Any modifications or derivative works of this code must retain this
# copyright notice, and modified files need to carry a notice indicating
# that they have been altered from the originals.

import setuptools
import os
import os.path
import importlib.util

# Parse the version file
spec = importlib.util.spec_from_file_location("qtealeaves", "./qtealeaves/version.py")
version_module = importlib.util.module_from_spec(spec)
spec.loader.exec_module(version_module)

# Get the readme file
with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="qtealeaves",
    version=version_module.__version__,
    author=", ".join(
        [
            "Marco Ballarin",
            "Giovanni Cataldi",
            "Aurora Costantini",
            "Daniel Jaschke",
            "Giuseppe Magnifico",
            "Simone Notarnicola",
            "Alice Pagano",
            "Marco Rigobello",
            "Nora Reinić",
        ]
    ),
    author_email="",
    description="Interface tensor network simulations",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://baltig.infn.it/quantum_tea_leaves_internal/py_api_quantum_tea_leaves.git",
    project_urls={},
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
    ],
    package_dir={
        "qtealeaves": "qtealeaves",
        "qtealeaves.emulator": "qtealeaves/emulator",
        "qtealeaves.observables": "qtealeaves/observables",
        "qtealeaves.modeling": "qtealeaves/modeling",
        "qtealeaves.models": "qtealeaves/models",
        "qtealeaves.operators": "qtealeaves/operators",
        "qtealeaves.convergence_parameters": "qtealeaves/convergence_parameters",
    },
    packages=[
        "qtealeaves",
        "qtealeaves.emulator",
        "qtealeaves.observables",
        "qtealeaves.modeling",
        "qtealeaves.models",
        "qtealeaves.operators",
        "qtealeaves.convergence_parameters",
    ],
    python_requires=">=3.6",
)
